@@ -15,9 +15,8 @@
 
 import abc
 
-from neutron.common import constants as nc_const
-from neutron.common import rpc as n_rpc
 from neutron.db import agents_db
+from neutron_lib import rpc as n_rpc
 
 from networking_l2gw._i18n import _
 from networking_l2gw.db.l2gateway import l2gateway_db as l2_gw_db
@@ -59,7 +58,7 @@ class L2gwRpcDriver(service_drivers.L2gwDriver):
             L2GW_CALLBACK, self)
         self.endpoints = (
             [self.ovsdb_callback, agents_db.AgentExtRpcCallback()])
-        self.conn = n_rpc.create_connection()
+        self.conn = n_rpc.Connection()
         self.conn.create_consumer(topics.L2GATEWAY_PLUGIN,
                                   self.endpoints,
                                   fanout=False)
@@ -556,7 +555,7 @@ class L2gwRpcDriver(service_drivers.L2gwDriver):
             })
         for agent in agents:
             conf_dict = agent.get("configurations")
-            if conf_dict.get("agent_mode") == nc_const.L3_AGENT_MODE_DVR_SNAT:
+            if conf_dict.get("agent_mode") == n_const.L3_AGENT_MODE_DVR_SNAT:
                 hostname = agent.get('host')
                 for endpoint in endpoints:
                     if endpoint.get('host') == hostname:
